@@ -4,8 +4,8 @@ from WebKit import *
 
 class TestDOMImplementation (TestCase):
     def testMethods(self):
-        self.failUnlessResultIsBOOL(DOMImplementation.hasFeature_version_)
-        self.failUnlessResultIsBOOL(DOMImplementation.hasFeature__)
+        self.assertResultIsBOOL(DOMImplementation.hasFeature_version_)
+        self.assertResultIsBOOL(DOMImplementation.hasFeature__)
 
 if __name__ == "__main__":
     main()
